Changelog
=========

1.1.2 (2015-07-15)
------------------

SciSalt.matplotlib
^^^^^^^^^^^^^^^^^^

* Imshow_Slider

  * Renamed imshow_slider -> Imshow_Slider
  * Colorbar options added
  * Attribute *p* changed to *AxesImage*

* setup_figure

  * Changed arguments from *gridspec_(x/y)* to *rows* and *cols*
  * Added *figsize* control

* Added RectangleSelector
* Added setup_axes


1.1.1 (2015-07-12)
------------------

* First release on PyPI
